@@ -11,14 +11,12 @@ from telegram_util import cutCaption, isUrl, cutCaptionHtml
 import os
 import time
 
-last_sent = {}
+next_send_time = {}
 def waitSend(chat_id, media_group_size):
-	if chat_id in last_sent:
-		elapsed = time.time() - last_sent[chat_id]
-		to_sleep = media_group_size ** 2 + media_group_size * 15
-		if to_sleep > elapsed:
-			time.sleep(to_sleep - elapsed)
-	last_sent[chat_id] = time.time()
+	wait = next_send_time.get(chat_id, 0) + media_group_size ** 2 + media_group_size * 10 - time.time()
+	if wait > 0:
+		time.sleep(wait)
+	next_send_time[chat_id] = time.time() + media_group_size ** 2 + media_group_size * 10
 
 def properSize(fn):
 	size = os.stat(fn).st_size
@@ -105,6 +103,7 @@ def send_v2(chat, result, rotate=0, send_all=False, no_cut=False, size_factor =
 		return return_result
 
 	if result.cap or result.cap_html or result.cap_html_v2:
+		waitSend(chat.id, 1)
 		return [chat.send_message(getCap(result, 4000), 
 			parse_mode=result.getParseMode(), timeout = 20*60, 
 			disable_web_page_preview = (not isUrl(result.cap)))]
